@@ -1,12 +1,10 @@
 package Search::Elasticsearch::Cxn::NetCurl;
 
 use Moo;
-with 'Search::Elasticsearch::Role::Cxn::HTTP',
-    'Search::Elasticsearch::Role::Cxn',
-    'Search::Elasticsearch::Role::Is_Sync';
+with 'Search::Elasticsearch::Role::Cxn', 'Search::Elasticsearch::Role::Is_Sync';
 
-use Search::Elasticsearch 2.03;
-our $VERSION = "2.03";
+use Search::Elasticsearch 5.00;
+our $VERSION = "5.00";
 
 use HTTP::Parser::XS qw(HEADERS_AS_HASHREF parse_http_response);
 use Try::Tiny;
@@ -49,8 +47,7 @@ sub perform_request {
     $handle->setopt( CURLOPT_URL,           $uri );
     $handle->setopt( CURLOPT_CUSTOMREQUEST, $method );
 
-    $handle->setopt( CURLOPT_CONNECTTIMEOUT_MS,
-        $self->connect_timeout * 1000 );
+    $handle->setopt( CURLOPT_CONNECTTIMEOUT_MS, $self->connect_timeout * 1000 );
     $handle->setopt( CURLOPT_TIMEOUT_MS,
         1000 * ( $params->{timeout} || $self->request_timeout ) );
 
@@ -58,8 +55,10 @@ sub perform_request {
 
     my $data = $params->{data};
     if ( defined $data ) {
-        $headers{'Content-Type'} = $params->{mime_type};
-        $headers{'Expect'}       = '';
+        $headers{'Content-Type'}     = $params->{mime_type};
+        $headers{'Expect'}           = '';
+        $headers{'Content-Encoding'} = $params->{encoding}
+            if $params->{encoding};
         $handle->setopt( CURLOPT_POSTFIELDS,    $data );
         $handle->setopt( CURLOPT_POSTFIELDSIZE, length $data );
     }
@@ -149,7 +148,7 @@ Search::Elasticsearch::Cxn::NetCurl - A Cxn implementation which uses libcurl vi
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -157,7 +156,7 @@ Provides an HTTP Cxn class based on L<Net::Curl>.
 The C<NetCurl> Cxn class is very fast and uses persistent connections but
 requires XS and C<libcurl>.
 
-This class does L<Search::Elasticsearch::Role::Cxn::HTTP>, whose documentation
+This class does L<Search::Elasticsearch::Role::Cxn>, whose documentation
 provides more information.
 
 =head1 CONFIGURATION
@@ -170,22 +169,18 @@ environment with low network latency.
 
 =head2 Inherited configuration
 
-From L<Search::Elasticsearch::Role::Cxn::HTTP>
-
-=over
-
-=item * L<node|Search::Elasticsearch::Role::Cxn::HTTP/"node">
-
-=item * L<max_content_length|Search::Elasticsearch::Role::Cxn::HTTP/"max_content_length">
-
-=item * L<deflate|Search::Elasticsearch::Role::Cxn::HTTP/"deflate">
-
-=back
-
 From L<Search::Elasticsearch::Role::Cxn>
 
 =over
 
+=item * L<node|Search::Elasticsearch::Role::Cxn/"node">
+
+=item * L<max_content_length|Search::Elasticsearch::Role::Cxn/"max_content_length">
+
+=item * L<deflate|Search::Elasticsearch::Role::Cxn/"gzip">
+
+=item * L<deflate|Search::Elasticsearch::Role::Cxn/"deflate">
+
 =item * L<request_timeout|Search::Elasticsearch::Role::Cxn/"request_timeout">
 
 =item * L<ping_timeout|Search::Elasticsearch::Role::Cxn/"ping_timeout">
@@ -278,28 +273,22 @@ error if the request failed.
 
 =head2 Inherited methods
 
-From L<Search::Elasticsearch::Role::Cxn::HTTP>
-
-=over
-
-=item * L<scheme()|Search::Elasticsearch::Role::Cxn::HTTP/"scheme()">
-
-=item * L<is_https()|Search::Elasticsearch::Role::Cxn::HTTP/"is_https()">
-
-=item * L<userinfo()|Search::Elasticsearch::Role::Cxn::HTTP/"userinfo()">
-
-=item * L<default_headers()|Search::Elasticsearch::Role::Cxn::HTTP/"default_headers()">
-
-=item * L<max_content_length()|Search::Elasticsearch::Role::Cxn::HTTP/"max_content_length()">
-
-=item * L<build_uri()|Search::Elasticsearch::Role::Cxn::HTTP/"build_uri()">
-
-=back
-
 From L<Search::Elasticsearch::Role::Cxn>
 
 =over
 
+=item * L<scheme()|Search::Elasticsearch::Role::Cxn/"scheme()">
+
+=item * L<is_https()|Search::Elasticsearch::Role::Cxn/"is_https()">
+
+=item * L<userinfo()|Search::Elasticsearch::Role::Cxn/"userinfo()">
+
+=item * L<default_headers()|Search::Elasticsearch::Role::Cxn/"default_headers()">
+
+=item * L<max_content_length()|Search::Elasticsearch::Role::Cxn/"max_content_length()">
+
+=item * L<build_uri()|Search::Elasticsearch::Role::Cxn/"build_uri()">
+
 =item * L<host()|Search::Elasticsearch::Role::Cxn/"host()">
 
 =item * L<port()|Search::Elasticsearch::Role::Cxn/"port()">
@@ -332,7 +321,7 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =over
 
-=item * L<Search::Elasticsearch::Role::Cxn::HTTP>
+=item * L<Search::Elasticsearch::Role::Cxn>
 
 =item * L<Search::Elasticsearch::Cxn::Hijk>
 
